/*  smplayer, GUI front-end for mplayer.
    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "myactiongroup.h"
#include <QAction>
#include <QList>

MyActionGroupItem::MyActionGroupItem(QObject * parent, MyActionGroup *group,
                                     const QString & name, 
                                     int data, bool autoadd)
	: MyAction(parent, name, autoadd)
{
	setData(data);
	setCheckable(true);
	if (group) group->addAction(this);
}


MyActionGroup::MyActionGroup( QObject * parent ) : QActionGroup(parent)
{
	setExclusive(true);
	connect( this, SIGNAL(triggered(QAction *)), 
             this, SLOT(itemTriggered(QAction *)) );
}

void MyActionGroup::setChecked(int ID) {
	QList <QAction *> l = actions();
	for (int n=0; n < l.count(); n++) {
		if (l[n]->data().toInt() == ID) {
			l[n]->setChecked(true);
			return;
		}
	}
}

int MyActionGroup::checked() {
	QAction * a = checkedAction();
	if (a) 
		return a->data().toInt();
	else
		return -1;
}

void MyActionGroup::clear() {
}

void MyActionGroup::itemTriggered(QAction *a) {
	qDebug("MyActionGroup::itemTriggered: '%s'", a->objectName().toUtf8().data());
	int value = a->data().toInt();

	qDebug("MyActionGroup::itemTriggered: ID: %d", value);

	emit activated(value);
}
